


########################################################################################
#
#######################################################################################
class SiLog:
        
    ########################################################################################
    #
    #######################################################################################
    @staticmethod
    def Message(msg):
        print("{}".format(msg))


    ########################################################################################
    #
    #######################################################################################
    @staticmethod
    def Error(err):
        raise Exception(str(err))

    ########################################################################################
    #
    #######################################################################################
    @staticmethod
    def Unsupported(val):
        raise Exception("unsupported [{}]".format(val))
    

    ########################################################################################
    #
    #######################################################################################
    @staticmethod
    def KeyVal(key, val):
        print("{} [{}]".format(key, val))

